@@ -20,7 +20,6 @@ class ApiClient:
     """Class for a single API endpoint."""
 
     default_headers = {
-        # 'User-agent': 'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/535.2 (KHTML, like Gecko) Chrome/15.0.874.121 Safari/535.2'
         "User-Agent": "Mozilla/5.0 (Macintosh; Intel Mac OS X 10.14; rv:66.0) Gecko/20100101 Firefox/66.0"
     }
 
@@ -149,6 +148,9 @@ class Garmin:
         self.garmin_connect_daily_hydration_url = (
             "proxy/usersummary-service/usersummary/hydration/daily"
         )
+        self.garmin_connect_daily_stats_steps_url = (
+            "proxy/usersummary-service/stats/steps/daily"
+        )
         self.garmin_connect_personal_record_url = (
             "proxy/personalrecord-service/personalrecord/prs"
         )
@@ -445,6 +447,14 @@ class Garmin:
 
         return self.modern_rest_client.get(url, params=params).json()
 
+    def get_daily_steps(self, start, end):
+        """Fetch available steps data 'start' and 'end' format 'YYYY-MM-DD'."""
+
+        url = f'{self.garmin_connect_daily_stats_steps_url}/{start}/{end}'
+        logger.debug("Requesting daily steps data")
+
+        return self.modern_rest_client.get(url).json()
+
     def get_heart_rates(self, cdate):
         """Fetch available heart rates data 'cDate' format 'YYYY-MM-DD'."""
 
